import { IStandardHeader } from './set/standard_header'
import { IParties } from './set/parties'
import { IContraGrp } from './set/contra_grp'
import { IInstrument } from './set/instrument'
import { IFinancingDetails } from './set/financing_details'
import { IUndInstrmtGrp } from './set/und_instrmt_grp'
import { IStipulations } from './set/stipulations'
import { IOrderQtyData } from './set/order_qty_data'
import { IPegInstructions } from './set/peg_instructions'
import { IDiscretionInstructions } from './set/discretion_instructions'
import { ICommissionData } from './set/commission_data'
import { ISpreadOrBenchmarkCurveData } from './set/spread_or_benchmark_curve_data'
import { IYieldData } from './set/yield_data'
import { IContAmtGrp } from './set/cont_amt_grp'
import { IInstrmtLegExecGrp } from './set/instrmt_leg_exec_grp'
import { IMiscFeesGrp } from './set/misc_fees_grp'
import { IStrategyParametersGrp } from './set/strategy_parameters_grp'
import { ITrdRegTimestamps } from './set/trd_reg_timestamps'
import { ITriggeringInstruction } from './set/triggering_instruction'
import { IDisplayInstruction } from './set/display_instruction'
import { IStandardTrailer } from './set/standard_trailer'

export interface IExecutionReport {
  StandardHeader: IStandardHeader// [1] BeginString.8, BodyLength.9 .. CstmApplVerID.1129
  OrderID: string// [2] 37 (String)
  SecondaryOrderID?: string// [3] 198 (String)
  SecondaryClOrdID?: string// [4] 526 (String)
  SecondaryExecID?: string// [5] 527 (String)
  ClOrdID?: string// [6] 11 (String)
  OrigClOrdID?: string// [7] 41 (String)
  ClOrdLinkID?: string// [8] 583 (String)
  QuoteRespID?: string// [9] 693 (String)
  OrdStatusReqID?: string// [10] 790 (String)
  MassStatusReqID?: string// [11] 584 (String)
  TotNumReports?: number// [12] 911 (Int)
  LastRptRequested?: boolean// [13] 912 (Boolean)
  Parties?: IParties// [14] NoPartyIDs.453, PartyID.448 .. PartySubIDType.803
  TradeOriginationDate?: Date// [15] 229 (LocalDate)
  ContraGrp?: IContraGrp// [16] NoContraBrokers.382, ContraBroker.375 .. ContraLegRefID.655
  ListID?: string// [17] 66 (String)
  CrossID?: string// [18] 548 (String)
  OrigCrossID?: string// [19] 551 (String)
  CrossType?: number// [20] 549 (Int)
  ExecID: string// [21] 17 (String)
  ExecRefID?: string// [22] 19 (String)
  ExecType: string// [23] 150 (String)
  OrdStatus: string// [24] 39 (String)
  WorkingIndicator?: boolean// [25] 636 (Boolean)
  OrdRejReason?: number// [26] 103 (Int)
  ExecRestatementReason?: number// [27] 378 (Int)
  Account?: string// [28] 1 (String)
  AcctIDSource?: number// [29] 660 (Int)
  AccountType?: number// [30] 581 (Int)
  DayBookingInst?: string// [31] 589 (String)
  BookingUnit?: string// [32] 590 (String)
  PreallocMethod?: string// [33] 591 (String)
  SettlType?: string// [34] 63 (String)
  SettlDate?: Date// [35] 64 (LocalDate)
  CashMargin?: string// [36] 544 (String)
  ClearingFeeIndicator?: string// [37] 635 (String)
  NumericOrderID?: string// [38] 29500 (String)
  Instrument?: IInstrument// [39] Symbol.55, SymbolSfx.65 .. TradingDeadline.5517
  FinancingDetails?: IFinancingDetails// [40] AgreementDesc.913, AgreementID.914 .. MarginRatio.898
  UndInstrmtGrp?: IUndInstrmtGrp// [41] NoUnderlyings.711, UnderlyingSymbol.311 .. UnderlyingFXRateCalc.1046
  Side: string// [42] 54 (String)
  Stipulations?: IStipulations// [43] NoStipulations.232, StipulationType.233, StipulationValue.234
  QtyType?: number// [44] 854 (Int)
  OrderQtyData?: IOrderQtyData// [45] OrderQty.38, CashOrderQty.152 .. RoundingModulus.469
  OrdType?: string// [46] 40 (String)
  PriceType?: number// [47] 423 (Int)
  Price?: number// [48] 44 (Float)
  StopPx?: number// [49] 99 (Float)
  PegInstructions?: IPegInstructions// [50] PegOffsetValue.211, PegMoveType.835 .. PegSecurityDesc.1099
  DiscretionInstructions?: IDiscretionInstructions// [51] DiscretionInst.388, DiscretionOffsetValue.389 .. DiscretionScope.846
  PeggedPrice?: number// [52] 839 (Float)
  DiscretionPrice?: number// [53] 845 (Float)
  TargetStrategy?: number// [54] 847 (Int)
  TargetStrategyParameters?: string// [55] 848 (String)
  ParticipationRate?: number// [56] 849 (Float)
  TargetStrategyPerformance?: number// [57] 850 (Float)
  Currency?: string// [58] 15 (String)
  ComplianceID?: string// [59] 376 (String)
  SolicitedFlag?: boolean// [60] 377 (Boolean)
  TimeInForce?: string// [61] 59 (String)
  EffectiveTime?: Date// [62] 168 (UtcTimestamp)
  ExpireDate?: Date// [63] 432 (LocalDate)
  ExpireTime?: Date// [64] 126 (UtcTimestamp)
  ExecInst?: string// [65] 18 (String)
  OrderCapacity?: string// [66] 528 (String)
  OrderRestrictions?: string// [67] 529 (String)
  CustOrderCapacity?: number// [68] 582 (Int)
  LastQty?: number// [69] 32 (Float)
  UnderlyingLastQty?: number// [70] 652 (Float)
  LastPx?: number// [71] 31 (Float)
  UnderlyingLastPx?: number// [72] 651 (Float)
  LastParPx?: number// [73] 669 (Float)
  LastSpotRate?: number// [74] 194 (Float)
  LastForwardPoints?: number// [75] 195 (Float)
  LastMkt?: string// [76] 30 (String)
  TradingSessionID?: string// [77] 336 (String)
  TradingSessionSubID?: string// [78] 625 (String)
  TimeBracket?: string// [79] 943 (String)
  LastCapacity?: string// [80] 29 (String)
  LeavesQty: number// [81] 151 (Float)
  CumQty: number// [82] 14 (Float)
  AvgPx?: number// [83] 6 (Float)
  DayOrderQty?: number// [84] 424 (Float)
  DayCumQty?: number// [85] 425 (Float)
  DayAvgPx?: number// [86] 426 (Float)
  GTBookingInst?: number// [87] 427 (Int)
  TradeDate?: Date// [88] 75 (LocalDate)
  TransactTime?: Date// [89] 60 (UtcTimestamp)
  ReportToExch?: boolean// [90] 113 (Boolean)
  CommissionData?: ICommissionData// [91] Commission.12, CommType.13 .. FundRenewWaiv.497
  SpreadOrBenchmarkCurveData?: ISpreadOrBenchmarkCurveData// [92] Spread.218, BenchmarkCurveCurrency.220 .. BenchmarkSecurityIDSource.761
  YieldData?: IYieldData// [93] YieldType.235, Yield.236 .. YieldRedemptionPriceType.698
  GrossTradeAmt?: number// [94] 381 (Float)
  NumDaysInterest?: number// [95] 157 (Int)
  ExDate?: Date// [96] 230 (LocalDate)
  AccruedInterestRate?: number// [97] 158 (Float)
  AccruedInterestAmt?: number// [98] 159 (Float)
  InterestAtMaturity?: number// [99] 738 (Float)
  EndAccruedInterestAmt?: number// [100] 920 (Float)
  StartCash?: number// [101] 921 (Float)
  EndCash?: number// [102] 922 (Float)
  TradedFlatSwitch?: boolean// [103] 258 (Boolean)
  BasisFeatureDate?: Date// [104] 259 (LocalDate)
  BasisFeaturePrice?: number// [105] 260 (Float)
  Concession?: number// [106] 238 (Float)
  TotalTakedown?: number// [107] 237 (Float)
  NetMoney?: number// [108] 118 (Float)
  SettlCurrAmt?: number// [109] 119 (Float)
  SettlCurrency?: string// [110] 120 (String)
  SettlCurrFxRate?: number// [111] 155 (Float)
  SettlCurrFxRateCalc?: string// [112] 156 (String)
  HandlInst?: string// [113] 21 (String)
  MinQty?: number// [114] 110 (Float)
  MaxFloor?: number// [115] 111 (Float)
  PositionEffect?: string// [116] 77 (String)
  MaxShow?: number// [117] 210 (Float)
  BookingType?: number// [118] 775 (Int)
  Text?: string// [119] 58 (String)
  EncodedTextLen?: number// [120] 354 (Length)
  EncodedText?: Buffer// [121] 355 (RawData)
  SettlDate2?: Date// [122] 193 (LocalDate)
  OrderQty2?: number// [123] 192 (Float)
  LastForwardPoints2?: number// [124] 641 (Float)
  MultiLegReportingType?: string// [125] 442 (String)
  CancellationRights?: string// [126] 480 (String)
  MoneyLaunderingStatus?: string// [127] 481 (String)
  RegistID?: string// [128] 513 (String)
  Designation?: string// [129] 494 (String)
  TransBkdTime?: Date// [130] 483 (UtcTimestamp)
  ExecValuationPoint?: Date// [131] 515 (UtcTimestamp)
  ExecPriceType?: string// [132] 484 (String)
  ExecPriceAdjustment?: number// [133] 485 (Float)
  PriorityIndicator?: number// [134] 638 (Int)
  PriceImprovement?: number// [135] 639 (Float)
  LastLiquidityInd?: number// [136] 851 (Int)
  ContAmtGrp?: IContAmtGrp// [137] NoContAmts.518, ContAmtType.519 .. ContAmtCurr.521
  InstrmtLegExecGrp?: IInstrmtLegExecGrp// [138] NoLegs.555, LegSymbol.600 .. LegGrossTradeAmt.1075
  CopyMsgIndicator?: boolean// [139] 797 (Boolean)
  MiscFeesGrp?: IMiscFeesGrp// [140] NoMiscFees.136, MiscFeeAmt.137 .. MiscFeeBasis.891
  StrategyParametersGrp?: IStrategyParametersGrp// [141] NoStrategyParameters.957, StrategyParameterName.958 .. StrategyParameterValue.960
  HostCrossID?: string// [142] 961 (String)
  ManualOrderIndicator?: boolean// [143] 1028 (Boolean)
  CustDirectedOrder?: boolean// [144] 1029 (Boolean)
  ReceivedDeptID?: string// [145] 1030 (String)
  CustOrderHandlingInst?: string// [146] 1031 (String)
  OrderHandlingInstSource?: number// [147] 1032 (Int)
  TrdRegTimestamps?: ITrdRegTimestamps// [148] NoTrdRegTimestamps.768, TrdRegTimestamp.769 .. DeskOrderHandlingInst.1035
  AggressorIndicator?: boolean// [149] 1057 (Boolean)
  CalculatedCcyLastQty?: number// [150] 1056 (Float)
  LastSwapPoints?: number// [151] 1071 (Float)
  MatchType?: string// [152] 574 (String)
  OrderCategory?: string// [153] 1115 (String)
  LotType?: string// [154] 1093 (String)
  PriceProtectionScope?: string// [155] 1092 (String)
  TriggeringInstruction?: ITriggeringInstruction// [156] TriggerType.1100, TriggerAction.1101 .. TriggerTradingSessionSubID.1114
  PeggedRefPrice?: number// [157] 1095 (Float)
  PreTradeAnonymity?: boolean// [158] 1091 (Boolean)
  MatchIncrement?: number// [159] 1089 (Float)
  MaxPriceLevels?: number// [160] 1090 (Int)
  DisplayInstruction?: IDisplayInstruction// [161] SecondaryDisplayQty.1082, DisplayWhen.1083 .. DisplayQty.1138
  StandardTrailer: IStandardTrailer// [162] SignatureLength.93, Signature.89, CheckSum.10
}
