import { IStandardHeader } from './set/standard_header'
import { IQuotQualGrp } from './set/quot_qual_grp'
import { IParties } from './set/parties'
import { IInstrument } from './set/instrument'
import { IFinancingDetails } from './set/financing_details'
import { IUndInstrmtGrp } from './set/und_instrmt_grp'
import { IOrderQtyData } from './set/order_qty_data'
import { IStipulations } from './set/stipulations'
import { ILegQuotGrp } from './set/leg_quot_grp'
import { ISpreadOrBenchmarkCurveData } from './set/spread_or_benchmark_curve_data'
import { IYieldData } from './set/yield_data'
import { IStandardTrailer } from './set/standard_trailer'

export interface IQuote {
  StandardHeader: IStandardHeader// [1] BeginString.8, BodyLength.9 .. CstmApplVerID.1129
  QuoteReqID?: string// [2] 131 (String)
  QuoteReqServerID?: string// [3] 7124 (String)
  QuoteID: string// [4] 117 (String)
  QuoteMsgID?: string// [5] 1166 (String)
  QuoteRespID?: string// [6] 693 (String)
  QuoteType?: number// [7] 537 (Int)
  QuotQualGrp?: IQuotQualGrp// [8] NoQuoteQualifiers.735, QuoteQualifier.695
  QuoteResponseLevel?: number// [9] 301 (Int)
  Parties?: IParties// [10] NoPartyIDs.453, PartyID.448 .. PartySubIDType.803
  TradingSessionID?: string// [11] 336 (String)
  TradingSessionSubID?: string// [12] 625 (String)
  Instrument?: IInstrument// [13] Symbol.55, SymbolSfx.65 .. TradingDeadline.5517
  FinancingDetails?: IFinancingDetails// [14] AgreementDesc.913, AgreementID.914 .. MarginRatio.898
  UndInstrmtGrp?: IUndInstrmtGrp// [15] NoUnderlyings.711, UnderlyingSymbol.311 .. UnderlyingFXRateCalc.1046
  Side?: string// [16] 54 (String)
  OrderQtyData?: IOrderQtyData// [17] OrderQty.38, CashOrderQty.152 .. RoundingModulus.469
  SettlType?: string// [18] 63 (String)
  SettlDate?: Date// [19] 64 (LocalDate)
  SettlDate2?: Date// [20] 193 (LocalDate)
  OrderQty2?: number// [21] 192 (Float)
  Currency?: string// [22] 15 (String)
  Stipulations?: IStipulations// [23] NoStipulations.232, StipulationType.233, StipulationValue.234
  Account?: string// [24] 1 (String)
  AcctIDSource?: number// [25] 660 (Int)
  AccountType?: number// [26] 581 (Int)
  LegQuotGrp?: ILegQuotGrp// [27] NoLegs.555, LegSymbol.600 .. LegOfferForwardPoints.1068
  BidPx?: number// [28] 132 (Float)
  OfferPx?: number// [29] 133 (Float)
  MktBidPx?: number// [30] 645 (Float)
  MktOfferPx?: number// [31] 646 (Float)
  MinBidSize?: number// [32] 647 (Float)
  BidSize?: number// [33] 134 (Float)
  MinOfferSize?: number// [34] 648 (Float)
  OfferSize?: number// [35] 135 (Float)
  ValidUntilTime?: Date// [36] 62 (UtcTimestamp)
  BidSpotRate?: number// [37] 188 (Float)
  OfferSpotRate?: number// [38] 190 (Float)
  BidForwardPoints?: number// [39] 189 (Float)
  OfferForwardPoints?: number// [40] 191 (Float)
  MidPx?: number// [41] 631 (Float)
  BidYield?: number// [42] 632 (Float)
  MidYield?: number// [43] 633 (Float)
  OfferYield?: number// [44] 634 (Float)
  TransactTime?: Date// [45] 60 (UtcTimestamp)
  OrdType?: string// [46] 40 (String)
  BidForwardPoints2?: number// [47] 642 (Float)
  OfferForwardPoints2?: number// [48] 643 (Float)
  SettlCurrBidFxRate?: number// [49] 656 (Float)
  SettlCurrOfferFxRate?: number// [50] 657 (Float)
  SettlCurrFxRateCalc?: string// [51] 156 (String)
  CommType?: string// [52] 13 (String)
  Commission?: number// [53] 12 (Float)
  CustOrderCapacity?: number// [54] 582 (Int)
  ExDestination?: string// [55] 100 (String)
  OrderCapacity?: string// [56] 528 (String)
  PriceType?: number// [57] 423 (Int)
  SpreadOrBenchmarkCurveData?: ISpreadOrBenchmarkCurveData// [58] Spread.218, BenchmarkCurveCurrency.220 .. BenchmarkSecurityIDSource.761
  YieldData?: IYieldData// [59] YieldType.235, Yield.236 .. YieldRedemptionPriceType.698
  Text?: string// [60] 58 (String)
  EncodedTextLen?: number// [61] 354 (Length)
  EncodedText?: Buffer// [62] 355 (RawData)
  BidSwapPoints?: number// [63] 1065 (Float)
  OfferSwapPoints?: number// [64] 1066 (Float)
  ExDestinationIDSource?: string// [65] 1133 (String)
  StandardTrailer: IStandardTrailer// [66] SignatureLength.93, Signature.89, CheckSum.10
}
