import { IStandardHeader } from './set/standard_header'
import { IParties } from './set/parties'
import { IInstrument } from './set/instrument'
import { IFinancingDetails } from './set/financing_details'
import { IUndInstrmtGrp } from './set/und_instrmt_grp'
import { IOrderQtyData } from './set/order_qty_data'
import { IStipulations } from './set/stipulations'
import { ILegQuotStatGrp } from './set/leg_quot_stat_grp'
import { IQuotQualGrp } from './set/quot_qual_grp'
import { ISpreadOrBenchmarkCurveData } from './set/spread_or_benchmark_curve_data'
import { IYieldData } from './set/yield_data'
import { IStandardTrailer } from './set/standard_trailer'

export interface IQuoteStatusReport {
  StandardHeader: IStandardHeader// [1] BeginString.8, BodyLength.9 .. CstmApplVerID.1129
  QuoteStatusReqID?: string// [2] 649 (String)
  QuoteReqID?: string// [3] 131 (String)
  QuoteReqServerID?: string// [4] 7124 (String)
  QuoteID?: string// [5] 117 (String)
  QuoteMsgID?: string// [6] 1166 (String)
  QuoteRespID?: string// [7] 693 (String)
  QuoteType?: number// [8] 537 (Int)
  Parties?: IParties// [9] NoPartyIDs.453, PartyID.448 .. PartySubIDType.803
  TradingSessionID?: string// [10] 336 (String)
  TradingSessionSubID?: string// [11] 625 (String)
  Instrument?: IInstrument// [12] Symbol.55, SymbolSfx.65 .. TradingDeadline.5517
  FinancingDetails?: IFinancingDetails// [13] AgreementDesc.913, AgreementID.914 .. MarginRatio.898
  UndInstrmtGrp?: IUndInstrmtGrp// [14] NoUnderlyings.711, UnderlyingSymbol.311 .. UnderlyingFXRateCalc.1046
  Side?: string// [15] 54 (String)
  OrderQtyData?: IOrderQtyData// [16] OrderQty.38, CashOrderQty.152 .. RoundingModulus.469
  SettlType?: string// [17] 63 (String)
  SettlDate?: Date// [18] 64 (LocalDate)
  SettlDate2?: Date// [19] 193 (LocalDate)
  OrderQty2?: number// [20] 192 (Float)
  Currency?: string// [21] 15 (String)
  Stipulations?: IStipulations// [22] NoStipulations.232, StipulationType.233, StipulationValue.234
  Account?: string// [23] 1 (String)
  AcctIDSource?: number// [24] 660 (Int)
  AccountType?: number// [25] 581 (Int)
  LegQuotStatGrp?: ILegQuotStatGrp// [26] NoLegs.555, LegSymbol.600 .. LegOrderQty.685
  QuotQualGrp?: IQuotQualGrp// [27] NoQuoteQualifiers.735, QuoteQualifier.695
  ExpireTime?: Date// [28] 126 (UtcTimestamp)
  Price?: number// [29] 44 (Float)
  PriceType?: number// [30] 423 (Int)
  SpreadOrBenchmarkCurveData?: ISpreadOrBenchmarkCurveData// [31] Spread.218, BenchmarkCurveCurrency.220 .. BenchmarkSecurityIDSource.761
  YieldData?: IYieldData// [32] YieldType.235, Yield.236 .. YieldRedemptionPriceType.698
  BidPx?: number// [33] 132 (Float)
  OfferPx?: number// [34] 133 (Float)
  MktBidPx?: number// [35] 645 (Float)
  MktOfferPx?: number// [36] 646 (Float)
  MinBidSize?: number// [37] 647 (Float)
  BidSize?: number// [38] 134 (Float)
  MinOfferSize?: number// [39] 648 (Float)
  OfferSize?: number// [40] 135 (Float)
  ValidUntilTime?: Date// [41] 62 (UtcTimestamp)
  BidSpotRate?: number// [42] 188 (Float)
  OfferSpotRate?: number// [43] 190 (Float)
  BidForwardPoints?: number// [44] 189 (Float)
  OfferForwardPoints?: number// [45] 191 (Float)
  MidPx?: number// [46] 631 (Float)
  BidYield?: number// [47] 632 (Float)
  MidYield?: number// [48] 633 (Float)
  OfferYield?: number// [49] 634 (Float)
  TransactTime?: Date// [50] 60 (UtcTimestamp)
  OrdType?: string// [51] 40 (String)
  BidForwardPoints2?: number// [52] 642 (Float)
  OfferForwardPoints2?: number// [53] 643 (Float)
  SettlCurrBidFxRate?: number// [54] 656 (Float)
  SettlCurrOfferFxRate?: number// [55] 657 (Float)
  SettlCurrFxRateCalc?: string// [56] 156 (String)
  CommType?: string// [57] 13 (String)
  Commission?: number// [58] 12 (Float)
  CustOrderCapacity?: number// [59] 582 (Int)
  ExDestination?: string// [60] 100 (String)
  QuoteStatus?: number// [61] 297 (Int)
  Text?: string// [62] 58 (String)
  EncodedTextLen?: number// [63] 354 (Length)
  EncodedText?: Buffer// [64] 355 (RawData)
  ExDestinationIDSource?: string// [65] 1133 (String)
  StandardTrailer: IStandardTrailer// [66] SignatureLength.93, Signature.89, CheckSum.10
}
