import { IStandardHeader } from './set/standard_header'
import { IInstrument } from './set/instrument'
import { IFinancingDetails } from './set/financing_details'
import { IOrderQtyData } from './set/order_qty_data'
import { IYieldData } from './set/yield_data'
import { IUndInstrmtGrp } from './set/und_instrmt_grp'
import { ISpreadOrBenchmarkCurveData } from './set/spread_or_benchmark_curve_data'
import { IPositionAmountData } from './set/position_amount_data'
import { ITrdInstrmtLegGrp } from './set/trd_instrmt_leg_grp'
import { ITrdRegTimestamps } from './set/trd_reg_timestamps'
import { ITrdCapRptSideGrp } from './set/trd_cap_rpt_side_grp'
import { IRootParties } from './set/root_parties'
import { IStandardTrailer } from './set/standard_trailer'

export interface ITradeCaptureReport {
  StandardHeader: IStandardHeader// [1] BeginString.8, BodyLength.9 .. CstmApplVerID.1129
  TradeReportID?: string// [2] 571 (String)
  TradeReportTransType?: number// [3] 487 (Int)
  TradeReportType?: number// [4] 856 (Int)
  TradeRequestID?: string// [5] 568 (String)
  TrdType?: number// [6] 828 (Int)
  TrdSubType?: number// [7] 829 (Int)
  SecondaryTrdType?: number// [8] 855 (Int)
  TransferReason?: string// [9] 830 (String)
  ExecType?: string// [10] 150 (String)
  TotNumTradeReports?: number// [11] 748 (Int)
  LastRptRequested?: boolean// [12] 912 (Boolean)
  UnsolicitedIndicator?: boolean// [13] 325 (Boolean)
  SubscriptionRequestType?: string// [14] 263 (String)
  TradeReportRefID?: string// [15] 572 (String)
  SecondaryTradeReportRefID?: string// [16] 881 (String)
  SecondaryTradeReportID?: string// [17] 818 (String)
  TradeLinkID?: string// [18] 820 (String)
  TrdMatchID?: string// [19] 880 (String)
  ExecID?: string// [20] 17 (String)
  OrdStatus?: string// [21] 39 (String)
  SecondaryExecID?: string// [22] 527 (String)
  ExecRestatementReason?: number// [23] 378 (Int)
  PreviouslyReported?: boolean// [24] 570 (Boolean)
  PriceType?: number// [25] 423 (Int)
  MarketSegmentID?: string// [26] 1300 (String)
  NumericOrderID?: string// [27] 29500 (String)
  Instrument?: IInstrument// [28] Symbol.55, SymbolSfx.65 .. TradingDeadline.5517
  FinancingDetails?: IFinancingDetails// [29] AgreementDesc.913, AgreementID.914 .. MarginRatio.898
  OrderQtyData?: IOrderQtyData// [30] OrderQty.38, CashOrderQty.152 .. RoundingModulus.469
  QtyType?: number// [31] 854 (Int)
  YieldData?: IYieldData// [32] YieldType.235, Yield.236 .. YieldRedemptionPriceType.698
  UndInstrmtGrp?: IUndInstrmtGrp// [33] NoUnderlyings.711, UnderlyingSymbol.311 .. UnderlyingFXRateCalc.1046
  UnderlyingTradingSessionID?: string// [34] 822 (String)
  UnderlyingTradingSessionSubID?: string// [35] 823 (String)
  LastQty: number// [36] 32 (Float)
  LastPx: number// [37] 31 (Float)
  LastParPx?: number// [38] 669 (Float)
  LastSpotRate?: number// [39] 194 (Float)
  LastForwardPoints?: number// [40] 195 (Float)
  LastMkt?: string// [41] 30 (String)
  TradeDate?: Date// [42] 75 (LocalDate)
  ClearingBusinessDate?: Date// [43] 715 (LocalDate)
  AvgPx?: number// [44] 6 (Float)
  SpreadOrBenchmarkCurveData?: ISpreadOrBenchmarkCurveData// [45] Spread.218, BenchmarkCurveCurrency.220 .. BenchmarkSecurityIDSource.761
  AvgPxIndicator?: number// [46] 819 (Int)
  PositionAmountData?: IPositionAmountData// [47] NoPosAmt.753, PosAmtType.707 .. PositionCurrency.1055
  MultiLegReportingType?: string// [48] 442 (String)
  TradeLegRefID?: string// [49] 824 (String)
  TrdInstrmtLegGrp?: ITrdInstrmtLegGrp// [50] NoLegs.555, LegSymbol.600 .. LegGrossTradeAmt.1075
  TransactTime?: Date// [51] 60 (UtcTimestamp)
  TrdRegTimestamps?: ITrdRegTimestamps// [52] NoTrdRegTimestamps.768, TrdRegTimestamp.769 .. DeskOrderHandlingInst.1035
  SettlType?: string// [53] 63 (String)
  SettlDate?: Date// [54] 64 (LocalDate)
  MatchStatus?: string// [55] 573 (String)
  MatchType?: string// [56] 574 (String)
  TrdCapRptSideGrp?: ITrdCapRptSideGrp// [57] NoSides.552, Side.54 .. ExchangeSpecialInstructions.1139
  CopyMsgIndicator?: boolean// [58] 797 (Boolean)
  PublishTrdIndicator?: boolean// [59] 852 (Boolean)
  ShortSaleReason?: number// [60] 853 (Int)
  TrdRptStatus?: number// [61] 939 (Int)
  AsOfIndicator?: string// [62] 1015 (String)
  SettlSessID?: string// [63] 716 (String)
  SettlSessSubID?: string// [64] 717 (String)
  TierCode?: string// [65] 994 (String)
  MessageEventSource?: string// [66] 1011 (String)
  LastUpdateTime?: Date// [67] 779 (UtcTimestamp)
  RndPx?: number// [68] 991 (Float)
  TradeID?: string// [69] 1003 (String)
  SecondaryTradeID?: string// [70] 1040 (String)
  FirmTradeID?: string// [71] 1041 (String)
  SecondaryFirmTradeID?: string// [72] 1042 (String)
  CalculatedCcyLastQty?: number// [73] 1056 (Float)
  LastSwapPoints?: number// [74] 1071 (Float)
  UnderlyingSettlementDate?: Date// [75] 987 (LocalDate)
  GrossTradeAmt?: number// [76] 381 (Float)
  RootParties?: IRootParties// [77] NoRootPartyIDs.1116, RootPartyID.1117 .. RootPartySubIDType.1122
  OrderCategory?: string// [78] 1115 (String)
  TradeHandlingInstr?: string// [79] 1123 (String)
  OrigTradeHandlingInstr?: string// [80] 1124 (String)
  OrigTradeDate?: Date// [81] 1125 (LocalDate)
  OrigTradeID?: string// [82] 1126 (String)
  OrigSecondaryTradeID?: string// [83] 1127 (String)
  TZTransactTime?: string// [84] 1132 (String)
  ReportedPxDiff?: boolean// [85] 1134 (Boolean)
  RejectText?: string// [86] 1328 (String)
  StandardTrailer: IStandardTrailer// [87] SignatureLength.93, Signature.89, CheckSum.10
}
