import { IStandardHeader } from './set/standard_header'
import { IInstrument } from './set/instrument'
import { ITrdRegTimestamps } from './set/trd_reg_timestamps'
import { ITrdInstrmtLegGrp } from './set/trd_instrmt_leg_grp'
import { IPositionAmountData } from './set/position_amount_data'
import { ITrdCapRptAckSideGrp } from './set/trd_cap_rpt_ack_side_grp'
import { IRootParties } from './set/root_parties'
import { IUndInstrmtGrp } from './set/und_instrmt_grp'
import { IStandardTrailer } from './set/standard_trailer'

export interface ITradeCaptureReportAck {
  StandardHeader: IStandardHeader// [1] BeginString.8, BodyLength.9 .. CstmApplVerID.1129
  TradeReportID?: string// [2] 571 (String)
  TradeReportTransType?: number// [3] 487 (Int)
  TradeReportType?: number// [4] 856 (Int)
  TrdType?: number// [5] 828 (Int)
  TrdSubType?: number// [6] 829 (Int)
  SecondaryTrdType?: number// [7] 855 (Int)
  TransferReason?: string// [8] 830 (String)
  ExecType?: string// [9] 150 (String)
  TradeReportRefID?: string// [10] 572 (String)
  SecondaryTradeReportRefID?: string// [11] 881 (String)
  TrdRptStatus?: number// [12] 939 (Int)
  TradeReportRejectReason?: number// [13] 751 (Int)
  SecondaryTradeReportID?: string// [14] 818 (String)
  SubscriptionRequestType?: string// [15] 263 (String)
  TradeLinkID?: string// [16] 820 (String)
  TrdMatchID?: string// [17] 880 (String)
  ExecID?: string// [18] 17 (String)
  SecondaryExecID?: string// [19] 527 (String)
  Instrument?: IInstrument// [20] Symbol.55, SymbolSfx.65 .. TradingDeadline.5517
  TransactTime?: Date// [21] 60 (UtcTimestamp)
  TrdRegTimestamps?: ITrdRegTimestamps// [22] NoTrdRegTimestamps.768, TrdRegTimestamp.769 .. DeskOrderHandlingInst.1035
  ResponseTransportType?: number// [23] 725 (Int)
  ResponseDestination?: string// [24] 726 (String)
  Text?: string// [25] 58 (String)
  EncodedTextLen?: number// [26] 354 (Length)
  EncodedText?: Buffer// [27] 355 (RawData)
  TrdInstrmtLegGrp?: ITrdInstrmtLegGrp// [28] NoLegs.555, LegSymbol.600 .. LegGrossTradeAmt.1075
  ClearingFeeIndicator?: string// [29] 635 (String)
  OrdStatus?: string// [30] 39 (String)
  ExecRestatementReason?: number// [31] 378 (Int)
  PreviouslyReported?: boolean// [32] 570 (Boolean)
  PriceType?: number// [33] 423 (Int)
  UnderlyingTradingSessionID?: string// [34] 822 (String)
  QtyType?: number// [35] 854 (Int)
  UnderlyingTradingSessionSubID?: string// [36] 823 (String)
  LastQty?: number// [37] 32 (Float)
  LastPx?: number// [38] 31 (Float)
  LastParPx?: number// [39] 669 (Float)
  LastSpotRate?: number// [40] 194 (Float)
  LastForwardPoints?: number// [41] 195 (Float)
  LastMkt?: string// [42] 30 (String)
  TradeDate?: Date// [43] 75 (LocalDate)
  ClearingBusinessDate?: Date// [44] 715 (LocalDate)
  AvgPx?: number// [45] 6 (Float)
  AvgPxIndicator?: number// [46] 819 (Int)
  MultiLegReportingType?: string// [47] 442 (String)
  TradeLegRefID?: string// [48] 824 (String)
  SettlType?: string// [49] 63 (String)
  MatchStatus?: string// [50] 573 (String)
  MatchType?: string// [51] 574 (String)
  CopyMsgIndicator?: boolean// [52] 797 (Boolean)
  PublishTrdIndicator?: boolean// [53] 852 (Boolean)
  ShortSaleReason?: number// [54] 853 (Int)
  SettlDate?: Date// [55] 64 (LocalDate)
  SettlSessID?: string// [56] 716 (String)
  SettlSessSubID?: string// [57] 717 (String)
  PositionAmountData?: IPositionAmountData// [58] NoPosAmt.753, PosAmtType.707 .. PositionCurrency.1055
  TierCode?: string// [59] 994 (String)
  MessageEventSource?: string// [60] 1011 (String)
  LastUpdateTime?: Date// [61] 779 (UtcTimestamp)
  RndPx?: number// [62] 991 (Float)
  TrdCapRptAckSideGrp?: ITrdCapRptAckSideGrp// [63] NoSides.552, Side.54 .. SideTrdRegTimestampSrc.1014
  AsOfIndicator?: string// [64] 1015 (String)
  TradeID?: string// [65] 1003 (String)
  SecondaryTradeID?: string// [66] 1040 (String)
  FirmTradeID?: string// [67] 1041 (String)
  SecondaryFirmTradeID?: string// [68] 1042 (String)
  CalculatedCcyLastQty?: number// [69] 1056 (Float)
  LastSwapPoints?: number// [70] 1071 (Float)
  GrossTradeAmt?: number// [71] 381 (Float)
  RootParties?: IRootParties// [72] NoRootPartyIDs.1116, RootPartyID.1117 .. RootPartySubIDType.1122
  TradeHandlingInstr?: string// [73] 1123 (String)
  OrigTradeHandlingInstr?: string// [74] 1124 (String)
  OrigTradeDate?: Date// [75] 1125 (LocalDate)
  OrigTradeID?: string// [76] 1126 (String)
  OrigSecondaryTradeID?: string// [77] 1127 (String)
  UndInstrmtGrp?: IUndInstrmtGrp// [78] NoUnderlyings.711, UnderlyingSymbol.311 .. UnderlyingFXRateCalc.1046
  RptSys?: string// [79] 1135 (String)
  StandardTrailer: IStandardTrailer// [80] SignatureLength.93, Signature.89, CheckSum.10
}
